@@ -62,7 +62,10 @@ SAMPLES = [
 
 
 class HighLow(Dataset):
-    def __init__(self, **req):
+    def __init__(self):
+        pass
+
+    def _load(self, **req):
         self._fields = []
         for date, area, label in SAMPLES:
 
