@@ -7,14 +7,19 @@
 # nor does it submit to any jurisdiction.
 #
 
+import logging
+
 from . import Reader
 
+LOG = logging.getLogger(__name__)
+
+
 try:
     import codc as odc
 except Exception:
     import pyodc as odc
 
-    # print("Using pure Python odc decoder.", file=sys.stderr)
+    LOG.debug("Using pure Python odc decoder.")
 
 
 class ODBReader(Reader):
